@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.modules.qt.promotions
+   @package: main.modules.qt.promotions
       @file: hlabel.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -16,7 +16,7 @@ from typing import Optional
 
 from PyQt5.QtCore import pyqtSignal, Qt
 from PyQt5.QtGui import QFontMetrics, QResizeEvent, QTextDocument
-from PyQt5.QtWidgets import QLabel, QWidget, QSizePolicy
+from PyQt5.QtWidgets import QLabel, QSizePolicy, QWidget
 
 
 class HLabel(QLabel):
